@@ -45,11 +45,12 @@ use 5.006; # Only because of Lex::HookWrap. Otherwise 5.005
 use strict;
 use Test::Builder ();
 use Hook::LexWrap ();
-use base 'Exporter';
+use Exporter      ();
 
-use vars qw{$VERSION @EXPORT};
+use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '1.06';
+	$VERSION = '1.07';
+	@ISA     = 'Exporter';
 	@EXPORT  = qw{sub_track sub_calls sub_reset sub_reset_all};
 }
 
@@ -195,7 +196,7 @@ For other issues, or commercial enhancement or support, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -203,7 +204,7 @@ L<http://ali.as/>, L<Test::Builder>, L<Test::More>, L<Hook::LexWrap>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, 2006 Adam Kennedy. All rights reserved.
+Copyright (c) 2005, 2006 Adam Kennedy.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
